#ifndef SETTINGSWINDOW_H
#define SETTINGSWINDOW_H

#include <QDialog>
#include "settings.h"

namespace Ui {
    class SettingsWindow;
}

class SettingsWindow : public QDialog
{
    Q_OBJECT

public:
    explicit SettingsWindow(QWidget *parent = 0, Settings* settings=0);
    ~SettingsWindow();

private:
    Ui::SettingsWindow *ui;

    Settings* m_Settings;
    QStringList GetStyleSheets();

private slots:
    void CancelSlot();
    void SaveSlot();
    void StyleSlot(int index);
};

#endif // SETTINGSWINDOW_H
